# Name: 				jsMoveTool
# Author: 			Jan Sandstrom   www.pixero.com
# Description: 	Moves a selection with the arrow keys.
# Usage: 				1. Select a object or group of objects. 
# 							2. Select the JS MoveTool and enter a distance in the VCB. Press Return/Enter.
# 							3. Now move with arrow keys.
# 							4. Use Alt + Up/Down to move in Z axis.
# 							5. You can enter a new distance at any time.

require 'sketchup.rb'

class JS_MoveTool

def activate   
    # This sets the label for the VCB
    Sketchup::set_status_text "Distance", SB_VCB_LABEL
end

	model = Sketchup.active_model 
  entities = model.active_entities
  ss = model.selection


if RUBY_PLATFORM == "i386-mswin32" then                 # Win XP  
    $leftArrow = 37          # Arrow Left Key 
    $upArrow  = 38           # Arrow Up Key 
    $rightArrow  = 39        # Arrow Right Key 
    $downArrow = 40          # Arrow Down Key 
    $altKey = 18						 # Alt Key

elsif RUBY_PLATFORM == "powerpc-darwin" then            # Mac OSX 
    $leftArrow = 63234       # Arrow Left Key 
    $upArrow  = 63232        # Arrow Up Key 
    $rightArrow  = 63235     # Arrow Right Key 
    $downArrow = 63233       # Arrow Down Key 
    $altKey  = 524288        # Alt/Option Key 
end #if



  
  def onUserText (text, view)
    
    # The user may type in something that we can't parse as a length
    # so we set up some exception handling to trap that
    begin
        $value = text.to_l
    rescue
        # Error parsing the text
        UI.beep
        puts "Cannot convert #{text} to a Length"
        $value = nil
        Sketchup::set_status_text "", SB_VCB_VALUE
    end
    return if !$value
    
    Sketchup::set_status_text $value.to_s, SB_VCB_VALUE
  
      def onKeyDown(key, repeat, flags, view)
         # puts key   # For debug - finding the right keycodes
         
         if (key == $altKey)
         	$altDown = true;
         end #if
        
				@distance = $value
				
      	Sketchup.active_model.selection.each {|e|          

		
				# X axis
				if (key == $rightArrow) # Right 
					dist = Geom::Point3d.new [@distance, 0, 0]; 
				end #if
				if (key == $leftArrow) # Left 
				  	dist = Geom::Point3d.new [-@distance, 0, 0]; 
				end #if
				
				# Y axis 
				if (key == $upArrow) # Up
				 	dist = Geom::Point3d.new [0, @distance, 0]; 
				end #if
				if (key == $downArrow) # Down
				 	dist = Geom::Point3d.new [0, -@distance, 0]; 
				end #if

				# Z axis
				if ($altDown == true && key == $upArrow) # Alt + Up
				 	dist = Geom::Point3d.new [0, 0, @distance]; 
				end #if
				if ($altDown == true && key == $downArrow) # Alt + Down
				 	dist = Geom::Point3d.new [0, 0, -@distance]; 
				end #if

					
				# Now move it!	
		  	tr = Geom::Transformation.new (dist);
				Sketchup.active_model.entities.transform_entities(tr, e);	
				
    		} #each
      end #onKeyDown
    end #onUserText
    
    def onKeyUp(key, repeat, flags, view)
         
         if (key == $altKey)
         	$altDown = false;
         end #if
    end #def     
    
      
end # end of jsMoveTool

if( not file_loaded?("jsMoveTool.rb") )
    plugins_menu = UI.menu("Plugins")
    plugins_menu.add_item("JS MoveTool") { Sketchup.active_model.select_tool JS_MoveTool.new } 
end
